==> adminer-3.0.1.zip: adminer-3.0.1/adminer/lang/hu.inc.php <==
<?php
$translations = array(
	'Login' => 'Belépés',
	'Logout successful.' => 'Sikeres kilépés.',
	'Invalid credentials.' => 'Érvénytelen adatok.',
	'Server' => 'Szerver',
	'Username' => 'Felhasználó',
	'Password' => 'Jelszó',
	'Select database' => 'Adatbázis kiválasztása',
	'Invalid database.' => 'Érvénytelen adatbázis.',
	'Create new database' => 'Új adatbázis',
	'Table has been dropped.' => 'A tábla eldobva.',
	'Table has been altered.' => 'A tábla módosult.',
	'Table has been created.' => 'A tábla létrejött.',
	'Alter table' => 'Tábla módosítása',
	'Create table' => 'Tábla létrehozása',
	'Table name' => 'Tábla név',
	'engine' => 'motor',
	'collation' => 'egybevetés',
	'Column name' => 'Oszlop neve',
	'Type' => 'Típus',
	'Length' => 'Hossz',
	'Auto Increment' => 'Automatikus növelés',
	'Options' => 'Opciók',
	'Save' => 'Mentés',
	'Drop' => 'Eldob',
	'Database has been dropped.' => 'Az adatbázis eldobva.',
	'Database has been created.' => 'Az adatbázis létrejött.',
	'Database has been renamed.' => 'Az adadtbázis átnevezve.',
	'Database has been altered.' => 'Az adatbázis módosult.',
	'Alter database' => 'Adatbázis módosítása',
	'Create database' => 'Adatbázis létrehozása',
	'SQL command' => 'SQL parancs',
	'Dump' => 'Exportálás',
	'Logout' => 'Kilépés',
	'database' => 'adatbázis',
	'Use' => 'Használ',
	'No tables.' => 'Nincs tábla.',
	'select' => 'kiválaszt',
	'Create new table' => 'Új tábla',
	'Item has been deleted.' => 'A tétel törölve.',
	'Item has been updated.' => 'A tétel frissítve.',
	'Item%s has been inserted.' => '%s tétel beszúrva.',
	'Edit' => 'Szerkeszt',
	'Insert' => 'Beszúr',
	'Save and insert next' => 'Mentés és újat beszúr',
	'Delete' => 'Törlés',
	'Database' => 'Adatbázis',
	'Routines' => 'Rutinok',
	'Indexes have been altered.' => 'Az indexek megváltoztak.',
	'Indexes' => 'Indexek',
	'Alter indexes' => 'Index módosítása',
	'Add next' => 'Következő hozzáadása',
	'Language' => 'Nyelv',
	'Select' => 'Kiválaszt',
	'New item' => 'Új tétel',
	'Search' => 'Keresés',
	'Sort' => 'Sorba rendezés',
	'descending' => 'csökkenő',
	'Limit' => 'korlát',
	'No rows.' => 'Nincs megjeleníthető eredmény.',
	'Action' => 'Művelet',
	'edit' => 'szerkeszt',
	'Page' => 'oldal',
	'Query executed OK, %d row(s) affected.' => array('Lekérdezés sikeresen végrehajtva, %d sor érintett.', 'Lekérdezés sikeresen végrehajtva, %d sor érintett.', 'Lekérdezés sikeresen végrehajtva, %d sor érintett.'),
	'Error in query' => 'Hiba a lekérdezésben',
	'Execute' => 'Végrehajt',
	'Table' => 'Tábla',
	'Foreign keys' => 'Idegen kulcs',
	'Triggers' => 'Trigger',
	'View' => 'Nézet',
	'Unable to select the table' => 'Nem tudom kiválasztani a táblát',
	'Invalid CSRF token. Send the form again.' => 'Érvénytelen CSRF azonosító. Küldd újra az űrlapot.',
	'Comment' => 'Megjegyzés',
	'Default values' => 'Alapértelmezett értékek',
	'%d byte(s)' => array('%d bájt', '%d bájt', '%d bájt'),
	'No commands to execute.' => 'Nincs végrehajtható parancs.',
	'Unable to upload a file.' => 'Nem tudom feltölteni a fájlt.',
	'File upload' => 'Fájl feltöltése',
	'File uploads are disabled.' => 'A fájl feltöltés le van tiltva.',
	'Routine has been called, %d row(s) affected.' => array('Rutin meghívva, %d sor érintett.', 'Rutin meghívva, %d sor érintett.', 'Rutin meghívva, %d sor érintett.'),
	'Call' => 'Meghív',
	'No extension' => 'Nincs kiterjesztés',
	'None of the supported PHP extensions (%s) are available.' => 'Nincs egy elérhető támogatott PHP kiterjesztés (%s) sem.',
	'Session support must be enabled.' => 'A munkameneteknek (session) engedélyezve kell lennie.',
	'Session expired, please login again.' => 'Munkamenet lejárt, jelentkezz be újra.',
	'Text length' => 'Szöveg hossz',
	'Foreign key has been dropped.' => 'Idegen kulcs eldobva.',
	'Foreign key has been altered.' => 'Idegen kulcs módosult.',
	'Foreign key has been created.' => 'Idegen kulcs létrejött.',
	'Foreign key' => 'Idegen kulcs',
	'Target table' => 'Cél tábla',
	'Change' => 'Változtat',
	'Source' => 'Forrás',
	'Target' => 'Cél',
	'Add column' => 'Oszlop hozzáadása',
	'Alter' => 'Módosítás',
	'Add foreign key' => 'Idegen kulcs hozzadása',
	'ON DELETE' => 'törléskor',
	'ON UPDATE' => 'frissítéskor',
	'Index Type' => 'Index típusa',
	'Column (length)' => 'Oszop (méret)',
	'View has been dropped.' => 'A nézet eldobva.',
	'View has been altered.' => 'A nézet módosult.',
	'View has been created.' => 'A nézet létrejött.',
	'Alter view' => 'Nézet módosítása',
	'Create view' => 'Nézet létrehozása',
	'Name' => 'Név',
	'Process list' => 'Folyamatok',
	'%d process(es) have been killed.' => array('%d folyamat leállítva.', '%d folyamat leállítva.', '%d folyamat leállítva.'),
	'Kill' => 'Leállít',
	'Parameter name' => 'Paraméter neve',
	'Database schema' => 'Adatbázis séma',
	'Create procedure' => 'Eljárás létrehozása',
	'Create function' => 'Funkció létrehozása',
	'Routine has been dropped.' => 'A rutin eldobva.',
	'Routine has been altered.' => 'A rutin módosult.',
	'Routine has been created.' => 'A rutin létrejött.',
	'Alter function' => 'Funkció módosítása',
	'Alter procedure' => 'Eljárás módosítása',
	'Return type' => 'Visszatérési érték',
	'Add trigger' => 'Trigger hozzáadása',
	'Trigger has been dropped.' => 'A trigger eldobva.',
	'Trigger has been altered.' => 'A trigger módosult.',
	'Trigger has been created.' => 'A trigger létrejött.',
	'Alter trigger' => 'Trigger módosítása',
	'Create trigger' => 'Trigger létrehozása',
	'Time' => 'Idő',
	'Event' => 'Esemény',
	'%s version: %s through PHP extension %s' => '%s verzió: %s, PHP: %s',
	'%d row(s)' => array('%d sor', '%d sor', '%d sor'),
	'Remove' => 'Eltávolítás',
	'Are you sure?' => 'Biztos benne?',
	'Privileges' => 'Privilégiumok',
	'Create user' => 'Felhasználó hozzáadása',
	'User has been dropped.' => 'A felhasználó eldobva.',
	'User has been altered.' => 'A felhasználó módosult.',
	'User has been created.' => 'A felhasználó létrejött.',
	'Hashed' => 'Hashed',
	'Column' => 'Oszlop',
	'Routine' => 'Rutin',
	'Grant' => 'Engedélyezés',
	'Revoke' => 'Visszavonás',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Túl sok a POST adat! Csökkentsd az adat méretét, vagy növeld a %s beállítást.',
	'Logged as: %s' => 'Belépve: %s',
	'Move up' => 'Felfelé',
	'Move down' => 'Lefelé',
	'Functions' => 'Funkciók',
	'Aggregation' => 'Aggregálás',
	'Export' => 'Export',
	'Output' => 'Kimenet',
	'open' => 'megnyit',
	'save' => 'ment',
	'Format' => 'Formátum',
	'Tables' => 'Táblák',
	'Data' => 'Adat',
	'Event has been dropped.' => 'Az esemény eldobva.',
	'Event has been altered.' => 'Az esemény módosult.',
	'Event has been created.' => 'Az esemény létrejött.',
	'Alter event' => 'Esemény módosítása',
	'Create event' => 'Esemény létrehozása',
	'At given time' => 'Megadott időben',
	'Every' => 'Minden',
	'Events' => 'Esemény',
	'Schedule' => 'Ütemzés',
	'Start' => 'Kezd',
	'End' => 'Vége',
	'Status' => 'Állapot',
	'On completion preserve' => 'Befejezéskor megőrzi',
	'Tables and views' => 'Táblák és nézetek',
	'Data Length' => 'Méret',
	'Index Length' => 'Index hossz',
	'Data Free' => 'Adat szabad',
	'Collation' => 'Egybevetés',
	'Analyze' => 'Elemzés',
	'Optimize' => 'Optimalizál',
	'Check' => 'Ellenőrzés',
	'Repair' => 'Javít',
	'Truncate' => 'Felszabadít',
	'Tables have been truncated.' => 'A tábla felszabadítva.',
	'Rows' => 'Oszlop',
	',' => ' ',
	'Tables have been moved.' => 'Táblák áthelyezve.',
	'Move to other database' => 'Áthelyezés másik adatbázisba',
	'Move' => 'Áthelyez',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Mentés és szerkesztés folytatása',
	'original' => 'eredeti',
	'%d item(s) have been affected.' => array('%d tétel érintett.', '%d tétel érintett.', '%d tétel érintett.'),
	'whole result' => 'összes eredményt mutatása',
	'Tables have been dropped.' => 'Táblák eldobva.',
	'Clone' => 'Klónoz',
	'Partition by' => 'Rozdělit podle',
	'Partitions' => 'Particiók',
	'Partition name' => 'Partició neve',
	'Values' => 'Értékek',
	'%d row(s) have been imported.' => array('%d sor importálva.', '%d sor importálva.', '%d sor importálva.'),
	'CSV Import' => 'CSV importálása',
	'Import' => 'Importálás',
	'Show structure' => 'Struktúra',
	'Select data' => 'Tartalom',
	'Stop on error' => 'Hiba esetén megáll',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'A maximális mezőszámot elérted. Növeld meg ezeket: %s, %s.',
	'anywhere' => 'bárhol',
	'%.3f s' => '%.3f másodperc',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => 'Történet',
	'Variables' => 'Változók',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'A forrás és cél oszlopoknak azonos típusúak legyenek, a cél oszlopok indexeltek legyenek, és a hivatkozott adatnak léteznie kell.',
	'E-mail' => 'E-mail',
	'From' => 'Feladó',
	'Subject' => 'Tárgy',
	'Send' => 'Küldés',
	'%d e-mail(s) have been sent.' => array('%d e-mail elküldve.', '%d e-mail elküldve.', '%d e-mail elküldve.'),
	'Run file' => 'Fájl futtatása',
	'Numbers' => 'Szám',
	'Date and time' => 'Dátum és idő',
	'Strings' => 'Szöveg',
	'Binary' => 'Bináris',
	'Lists' => 'Lista',
	'Relations' => 'Reláció',
	'Maximum allowed file size is %sB.' => 'A maximális fájlméret %s B.',
	'Clear' => 'Törlés',
	'Editor' => 'Szerkesztő',
	'Webserver file %s' => 'Webszerver fájl %s',
	'File does not exist.' => 'A fájl nem létezik.',
	'Permanent login' => 'Emlékezz rám',
	'%d in total' => 'összesen %d',
	'Attachments' => 'Csatolmány',
	'System' => 'Adatbázis',
	'last' => 'utoljára',
	'Network' => 'Hálózat',
	'Geometry' => 'Geometria',
	'Databases have been dropped.' => 'Adatbázis eldobva.',
	'File exists.' => 'A fájl létezik.',
	'Double click on a value to modify it.' => 'Kattints kétszer az értékre a szerkesztéshez.',
	'Increase Text length to modify this value.' => 'Növeld a Szöveg hosszát, hogy módosítani tudd ezt az értéket.',
	'Use edit link to modify this value.' => 'Használd a szerkesztés hivatkozást ezen érték módosításához.',
	'Alter schema' => 'Séma módosítása',
	'Create schema' => 'Séma létrehozása',
	'Schema has been dropped.' => 'Séma eldobva.',
	'Schema has been created.' => 'Séma létrejött.',
	'Schema has been altered.' => 'Séma módosult.',
	'schema' => 'schéma',
	'Schema' => 'Schéma',
	'Sequences' => 'Sorozatok',
	'Create sequence' => 'Sorozat létrehozása',
	'Sequence has been dropped.' => 'Sorozat eldobva.',
	'Sequence has been created.' => 'Sorozat létrejött.',
	'Sequence has been altered.' => 'Sorozat módosult.',
	'Alter sequence' => 'Sorozat módosítása',
	'User types' => 'Felhasználói típus',
	'Create type' => 'Típus létrehozása',
	'Type has been dropped.' => 'Típus eldobva.',
	'Type has been created.' => 'Típus létrehozva.',
	'Alter type' => 'Típus módosítása',
	'Search data in tables' => 'Keresés a táblákban',
	'From server' => 'Szerverről',
	'empty' => 'üres',
	'now' => 'most',
);

==> adminer-3.1.0.zip: adminer-3.1.0/adminer/lang/hu.inc.php <==
<?php
$translations = array(
	'Login' => 'Belépés',
	'Logout successful.' => 'Sikeres kilépés.',
	'Invalid credentials.' => 'Érvénytelen adatok.',
	'Server' => 'Szerver',
	'Username' => 'Felhasználó',
	'Password' => 'Jelszó',
	'Select database' => 'Adatbázis kiválasztása',
	'Invalid database.' => 'Érvénytelen adatbázis.',
	'Create new database' => 'Új adatbázis',
	'Table has been dropped.' => 'A tábla eldobva.',
	'Table has been altered.' => 'A tábla módosult.',
	'Table has been created.' => 'A tábla létrejött.',
	'Alter table' => 'Tábla módosítása',
	'Create table' => 'Tábla létrehozása',
	'Table name' => 'Tábla név',
	'engine' => 'motor',
	'collation' => 'egybevetés',
	'Column name' => 'Oszlop neve',
	'Type' => 'Típus',
	'Length' => 'Hossz',
	'Auto Increment' => 'Automatikus növelés',
	'Options' => 'Opciók',
	'Save' => 'Mentés',
	'Drop' => 'Eldob',
	'Database has been dropped.' => 'Az adatbázis eldobva.',
	'Database has been created.' => 'Az adatbázis létrejött.',
	'Database has been renamed.' => 'Az adadtbázis átnevezve.',
	'Database has been altered.' => 'Az adatbázis módosult.',
	'Alter database' => 'Adatbázis módosítása',
	'Create database' => 'Adatbázis létrehozása',
	'SQL command' => 'SQL parancs',
	'Dump' => 'Exportálás',
	'Logout' => 'Kilépés',
	'database' => 'adatbázis',
	'Use' => 'Használ',
	'No tables.' => 'Nincs tábla.',
	'select' => 'kiválaszt',
	'Create new table' => 'Új tábla',
	'Item has been deleted.' => 'A tétel törölve.',
	'Item has been updated.' => 'A tétel frissítve.',
	'Item%s has been inserted.' => '%s tétel beszúrva.',
	'Edit' => 'Szerkeszt',
	'Insert' => 'Beszúr',
	'Save and insert next' => 'Mentés és újat beszúr',
	'Delete' => 'Törlés',
	'Database' => 'Adatbázis',
	'Routines' => 'Rutinok',
	'Indexes have been altered.' => 'Az indexek megváltoztak.',
	'Indexes' => 'Indexek',
	'Alter indexes' => 'Index módosítása',
	'Add next' => 'Következő hozzáadása',
	'Language' => 'Nyelv',
	'Select' => 'Kiválaszt',
	'New item' => 'Új tétel',
	'Search' => 'Keresés',
	'Sort' => 'Sorba rendezés',
	'descending' => 'csökkenő',
	'Limit' => 'korlát',
	'No rows.' => 'Nincs megjeleníthető eredmény.',
	'Action' => 'Művelet',
	'edit' => 'szerkeszt',
	'Page' => 'oldal',
	'Query executed OK, %d row(s) affected.' => array('Lekérdezés sikeresen végrehajtva, %d sor érintett.', 'Lekérdezés sikeresen végrehajtva, %d sor érintett.', 'Lekérdezés sikeresen végrehajtva, %d sor érintett.'),
	'Error in query' => 'Hiba a lekérdezésben',
	'Execute' => 'Végrehajt',
	'Table' => 'Tábla',
	'Foreign keys' => 'Idegen kulcs',
	'Triggers' => 'Trigger',
	'View' => 'Nézet',
	'Unable to select the table' => 'Nem tudom kiválasztani a táblát',
	'Invalid CSRF token. Send the form again.' => 'Érvénytelen CSRF azonosító. Küldd újra az űrlapot.',
	'Comment' => 'Megjegyzés',
	'Default values' => 'Alapértelmezett értékek',
	'%d byte(s)' => array('%d bájt', '%d bájt', '%d bájt'),
	'No commands to execute.' => 'Nincs végrehajtható parancs.',
	'Unable to upload a file.' => 'Nem tudom feltölteni a fájlt.',
	'File upload' => 'Fájl feltöltése',
	'File uploads are disabled.' => 'A fájl feltöltés le van tiltva.',
	'Routine has been called, %d row(s) affected.' => array('Rutin meghívva, %d sor érintett.', 'Rutin meghívva, %d sor érintett.', 'Rutin meghívva, %d sor érintett.'),
	'Call' => 'Meghív',
	'No extension' => 'Nincs kiterjesztés',
	'None of the supported PHP extensions (%s) are available.' => 'Nincs egy elérhető támogatott PHP kiterjesztés (%s) sem.',
	'Session support must be enabled.' => 'A munkameneteknek (session) engedélyezve kell lennie.',
	'Session expired, please login again.' => 'Munkamenet lejárt, jelentkezz be újra.',
	'Text length' => 'Szöveg hossz',
	'Foreign key has been dropped.' => 'Idegen kulcs eldobva.',
	'Foreign key has been altered.' => 'Idegen kulcs módosult.',
	'Foreign key has been created.' => 'Idegen kulcs létrejött.',
	'Foreign key' => 'Idegen kulcs',
	'Target table' => 'Cél tábla',
	'Change' => 'Változtat',
	'Source' => 'Forrás',
	'Target' => 'Cél',
	'Add column' => 'Oszlop hozzáadása',
	'Alter' => 'Módosítás',
	'Add foreign key' => 'Idegen kulcs hozzadása',
	'ON DELETE' => 'törléskor',
	'ON UPDATE' => 'frissítéskor',
	'Index Type' => 'Index típusa',
	'Column (length)' => 'Oszop (méret)',
	'View has been dropped.' => 'A nézet eldobva.',
	'View has been altered.' => 'A nézet módosult.',
	'View has been created.' => 'A nézet létrejött.',
	'Alter view' => 'Nézet módosítása',
	'Create view' => 'Nézet létrehozása',
	'Name' => 'Név',
	'Process list' => 'Folyamatok',
	'%d process(es) have been killed.' => array('%d folyamat leállítva.', '%d folyamat leállítva.', '%d folyamat leállítva.'),
	'Kill' => 'Leállít',
	'Parameter name' => 'Paraméter neve',
	'Database schema' => 'Adatbázis séma',
	'Create procedure' => 'Eljárás létrehozása',
	'Create function' => 'Funkció létrehozása',
	'Routine has been dropped.' => 'A rutin eldobva.',
	'Routine has been altered.' => 'A rutin módosult.',
	'Routine has been created.' => 'A rutin létrejött.',
	'Alter function' => 'Funkció módosítása',
	'Alter procedure' => 'Eljárás módosítása',
	'Return type' => 'Visszatérési érték',
	'Add trigger' => 'Trigger hozzáadása',
	'Trigger has been dropped.' => 'A trigger eldobva.',
	'Trigger has been altered.' => 'A trigger módosult.',
	'Trigger has been created.' => 'A trigger létrejött.',
	'Alter trigger' => 'Trigger módosítása',
	'Create trigger' => 'Trigger létrehozása',
	'Time' => 'Idő',
	'Event' => 'Esemény',
	'%s version: %s through PHP extension %s' => '%s verzió: %s, PHP: %s',
	'%d row(s)' => array('%d sor', '%d sor', '%d sor'),
	'Remove' => 'Eltávolítás',
	'Are you sure?' => 'Biztos benne?',
	'Privileges' => 'Privilégiumok',
	'Create user' => 'Felhasználó hozzáadása',
	'User has been dropped.' => 'A felhasználó eldobva.',
	'User has been altered.' => 'A felhasználó módosult.',
	'User has been created.' => 'A felhasználó létrejött.',
	'Hashed' => 'Hashed',
	'Column' => 'Oszlop',
	'Routine' => 'Rutin',
	'Grant' => 'Engedélyezés',
	'Revoke' => 'Visszavonás',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Túl sok a POST adat! Csökkentsd az adat méretét, vagy növeld a %s beállítást.',
	'Logged as: %s' => 'Belépve: %s',
	'Move up' => 'Felfelé',
	'Move down' => 'Lefelé',
	'Functions' => 'Funkciók',
	'Aggregation' => 'Aggregálás',
	'Export' => 'Export',
	'Output' => 'Kimenet',
	'open' => 'megnyit',
	'save' => 'ment',
	'Format' => 'Formátum',
	'Tables' => 'Táblák',
	'Data' => 'Adat',
	'Event has been dropped.' => 'Az esemény eldobva.',
	'Event has been altered.' => 'Az esemény módosult.',
	'Event has been created.' => 'Az esemény létrejött.',
	'Alter event' => 'Esemény módosítása',
	'Create event' => 'Esemény létrehozása',
	'At given time' => 'Megadott időben',
	'Every' => 'Minden',
	'Events' => 'Esemény',
	'Schedule' => 'Ütemzés',
	'Start' => 'Kezd',
	'End' => 'Vége',
	'Status' => 'Állapot',
	'On completion preserve' => 'Befejezéskor megőrzi',
	'Tables and views' => 'Táblák és nézetek',
	'Data Length' => 'Méret',
	'Index Length' => 'Index hossz',
	'Data Free' => 'Adat szabad',
	'Collation' => 'Egybevetés',
	'Analyze' => 'Elemzés',
	'Optimize' => 'Optimalizál',
	'Check' => 'Ellenőrzés',
	'Repair' => 'Javít',
	'Truncate' => 'Felszabadít',
	'Tables have been truncated.' => 'A tábla felszabadítva.',
	'Rows' => 'Oszlop',
	',' => ' ',
	'Tables have been moved.' => 'Táblák áthelyezve.',
	'Move to other database' => 'Áthelyezés másik adatbázisba',
	'Move' => 'Áthelyez',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Mentés és szerkesztés folytatása',
	'original' => 'eredeti',
	'%d item(s) have been affected.' => array('%d tétel érintett.', '%d tétel érintett.', '%d tétel érintett.'),
	'whole result' => 'összes eredményt mutatása',
	'Tables have been dropped.' => 'Táblák eldobva.',
	'Clone' => 'Klónoz',
	'Partition by' => 'Rozdělit podle',
	'Partitions' => 'Particiók',
	'Partition name' => 'Partició neve',
	'Values' => 'Értékek',
	'%d row(s) have been imported.' => array('%d sor importálva.', '%d sor importálva.', '%d sor importálva.'),
	'CSV Import' => 'CSV importálása',
	'Import' => 'Importálás',
	'Show structure' => 'Struktúra',
	'Select data' => 'Tartalom',
	'Stop on error' => 'Hiba esetén megáll',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'A maximális mezőszámot elérted. Növeld meg ezeket: %s, %s.',
	'anywhere' => 'bárhol',
	'%.3f s' => '%.3f másodperc',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => '[yyyy].m.d',
	'History' => 'Történet',
	'Variables' => 'Változók',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'A forrás és cél oszlopoknak azonos típusúak legyenek, a cél oszlopok indexeltek legyenek, és a hivatkozott adatnak léteznie kell.',
	'E-mail' => 'E-mail',
	'From' => 'Feladó',
	'Subject' => 'Tárgy',
	'Send' => 'Küldés',
	'%d e-mail(s) have been sent.' => array('%d e-mail elküldve.', '%d e-mail elküldve.', '%d e-mail elküldve.'),
	'Run file' => 'Fájl futtatása',
	'Numbers' => 'Szám',
	'Date and time' => 'Dátum és idő',
	'Strings' => 'Szöveg',
	'Binary' => 'Bináris',
	'Lists' => 'Lista',
	'Relations' => 'Reláció',
	'Maximum allowed file size is %sB.' => 'A maximális fájlméret %s B.',
	'Clear' => 'Törlés',
	'Editor' => 'Szerkesztő',
	'Webserver file %s' => 'Webszerver fájl %s',
	'File does not exist.' => 'A fájl nem létezik.',
	'Permanent login' => 'Emlékezz rám',
	'%d in total' => 'összesen %d',
	'Attachments' => 'Csatolmány',
	'System' => 'Adatbázis',
	'last' => 'utoljára',
	'Network' => 'Hálózat',
	'Geometry' => 'Geometria',
	'Databases have been dropped.' => 'Adatbázis eldobva.',
	'File exists.' => 'A fájl létezik.',
	'Double click on a value to modify it.' => 'Kattints kétszer az értékre a szerkesztéshez.',
	'Increase Text length to modify this value.' => 'Növeld a Szöveg hosszát, hogy módosítani tudd ezt az értéket.',
	'Use edit link to modify this value.' => 'Használd a szerkesztés hivatkozást ezen érték módosításához.',
	'Alter schema' => 'Séma módosítása',
	'Create schema' => 'Séma létrehozása',
	'Schema has been dropped.' => 'Séma eldobva.',
	'Schema has been created.' => 'Séma létrejött.',
	'Schema has been altered.' => 'Séma módosult.',
	'schema' => 'schéma',
	'Schema' => 'Schéma',
	'Sequences' => 'Sorozatok',
	'Create sequence' => 'Sorozat létrehozása',
	'Sequence has been dropped.' => 'Sorozat eldobva.',
	'Sequence has been created.' => 'Sorozat létrejött.',
	'Sequence has been altered.' => 'Sorozat módosult.',
	'Alter sequence' => 'Sorozat módosítása',
	'User types' => 'Felhasználói típus',
	'Create type' => 'Típus létrehozása',
	'Type has been dropped.' => 'Típus eldobva.',
	'Type has been created.' => 'Típus létrehozva.',
	'Alter type' => 'Típus módosítása',
	'Search data in tables' => 'Keresés a táblákban',
	'From server' => 'Szerverről',
	'empty' => 'üres',
	'now' => 'most',
	'%d query(s) executed OK.' => '%d sikeres lekérdezés.',
	'Show only errors' => 'Csak a hibák mutatása',
	'Last page' => 'Utolsó oldal',
	'Refresh' => 'Frissítés',
	'Invalid schema.' => 'Érvénytelen séma.',
	'Please use one of the extensions %s.' => 'Használja a(z) %s kiterjesztést.',
	'ltr' => 'ltr',
);
